# <img src="https://www.akashtrehan.com/assets/images/emoji/terminal.png" height="42" align="center"> SelSik

![Repo Boyutu](https://img.shields.io/github/repo-size/keyiflerolsun/SelSik?logo=git&logoColor=white)
![Görüntülenme](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/keyiflerolsun/SelSik&title=Görüntülenme)
<a href="https://KekikAkademi.org/Kahve" target="_blank"><img src="https://img.shields.io/badge/☕️-Kahve Ismarla-ffdd00" title="☕️ Kahve Ismarla" style="padding-left:5px;"></a>

![Python Version](https://img.shields.io/pypi/pyversions/SelSik?logo=python&logoColor=white)
![License](https://img.shields.io/pypi/l/SelSik?logo=gnu&logoColor=white)
![Status](https://img.shields.io/pypi/status/SelSik?logo=windowsterminal&logoColor=white)

![PyPI](https://img.shields.io/pypi/v/SelSik?logo=pypi&logoColor=white)
![PyPI - Downloads](https://img.shields.io/pypi/dm/SelSik?logo=pypi&logoColor=white)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/SelSik?logo=pypi&logoColor=white)

*İşlerimizi kolaylaştıracak fonksiyonların el altında durduğu kütüphane..*

[![ForTheBadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-love](http://ForTheBadge.com/images/badges/built-with-love.svg)](https://GitHub.com/keyiflerolsun/)

## 🚀 Kurulum

```bash
# Yüklemek
pip install SelSik

# Güncellemek
pip install -U SelSik
```

## <img src="https://i.imgur.com/ETZ1ABF.png" height="24" align="center"> Kullanım

```python
from SelSik import SelSik

selsik = SelSik()

# Bi Ara
```

## 💸 Bağış Yap

**[☕️ Kahve Ismarla](https://KekikAkademi.org/Kahve)**

## 🌐 Telif Hakkı ve Lisans

* *Copyright (C) 2022 by* [keyiflerolsun](https://github.com/keyiflerolsun) ❤️️
* [GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007](https://github.com/keyiflerolsun/SelSik/blob/master/LICENSE) *Koşullarına göre lisanslanmıştır..*

## ♻️ İletişim

*Benimle iletişime geçmek isterseniz, **Telegram**'dan mesaj göndermekten çekinmeyin;* [@keyiflerolsun](https://t.me/KekikKahve)

##

> **[@KekikAkademi](https://t.me/KekikAkademi)** *için yazılmıştır..*